@@ -10,7 +10,7 @@ use re '/aa';
 use Carp;
 use Errno;
 
-our $VERSION = '1.00';
+our $VERSION = '1.00_01';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(BACKUP_NONE
                  BACKUP_SINGLE
@@ -157,6 +157,7 @@ sub backup_copy_internal {
     unless (rename($fh->filename, $backup_name)) {
 	return _backup_copy_error("can't rename temporary file to $backup_name: $!");
     }
+    $fh->unlink_on_destroy(0);
     return $backup_name;
 }
 
