@@ -26,7 +26,7 @@ sub makefile {
     while ($size) {
 	my $n = @pattern;
 	$n = $size if $n > $size;
-	syswrite(FH, join('',@pattern[0..$n])) or
+	syswrite(FH, join('',@pattern[0..$n-1])) or
 		 croak "write error creating $file: $!";
 	$size -= $n;
     }
